@@ -54,6 +54,7 @@ copies.
 #include <stdio.h>
 #include <stdlib.h>
 #include "bresnham.h"
+#include "pendef.h"
 #include "hp2xx.h"
 
 
@@ -531,12 +532,12 @@ Byte	mask;
 				if ((i = x & 0x07) != 0)
 					mask >>= i;
 					
-if (pg->Clut[color_index][0]+pg->Clut[color_index][1]+pg->Clut[color_index][2] == 0){
- *(p_K +offset) |= mask;
+if (pt.clut[color_index][0]+pt.clut[color_index][1]+pt.clut[color_index][2] == 0){
+                *(p_K +offset) |= mask;
 }else{					
-		*(p_C + offset ) |= ( mask ^ ( pg->Clut[color_index][0] & mask ) );
-		*(p_M + offset ) |= ( mask ^ ( pg->Clut[color_index][1] & mask ) );
-		*(p_Y + offset ) |= ( mask ^ ( pg->Clut[color_index][2] & mask ) );
+		*(p_C + offset ) |= ( mask ^ ( pt.clut[color_index][0] & mask ) );
+		*(p_M + offset ) |= ( mask ^ ( pt.clut[color_index][1] & mask ) );
+		*(p_Y + offset ) |= ( mask ^ ( pt.clut[color_index][2] & mask ) );
 }					                        
 /*					
 				switch (color_index)
